@@ -7,14 +7,19 @@ use Catmandu::Store::DBI::Bag;
 use Moo;
 use namespace::clean;
 
-our $VERSION = "0.0505";
+our $VERSION = "0.0506";
 
 with 'Catmandu::Store';
+with 'Catmandu::Transactional';
 
 has data_source => (
     is => 'ro',
     required => 1,
-    trigger => sub { $_[0] =~ /^DBI:/i ? $_[0] : "DBI:$_[0]" },
+    trigger => sub {
+        my $ds = $_[0]->{data_source};
+        $ds = $ds =~ /^DBI:/i ? $ds : "DBI:$ds";
+        $_[0]->{data_source} = $ds;
+    },
 );
 has username => (is => 'ro', default => sub { '' });
 has password => (is => 'ro', default => sub { '' });
